<?php
/**
 * Gallery Section options
 *
 * @package Theme Palace
 * @subpackage Magazinews Pro
 * @since Magazinews Pro 1.0.0
 */

// Add Gallery section
$wp_customize->add_section( 'magazinews_pro_gallery_section', array(
	'title'             => esc_html__( 'Gallery','magazinews-pro' ),
	'description'       => esc_html__( 'Gallery Section options.', 'magazinews-pro' ),
	'panel'             => 'magazinews_pro_front_page_panel',
) );

// Gallery content enable control and setting
$wp_customize->add_setting( 'magazinews_pro_theme_options[gallery_section_enable]', array(
	'default'			=> 	$options['gallery_section_enable'],
	'sanitize_callback' => 'magazinews_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Magazinews_Pro_Switch_Control( $wp_customize, 'magazinews_pro_theme_options[gallery_section_enable]', array(
	'label'             => esc_html__( 'Gallery Section Enable', 'magazinews-pro' ),
	'section'           => 'magazinews_pro_gallery_section',
	'on_off_label' 		=> magazinews_pro_switch_options(),
) ) );

// gallery title setting and control
$wp_customize->add_setting( 'magazinews_pro_theme_options[gallery_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['gallery_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'magazinews_pro_theme_options[gallery_title]', array(
	'label'           	=> esc_html__( 'Title', 'magazinews-pro' ),
	'section'        	=> 'magazinews_pro_gallery_section',
	'active_callback' 	=> 'magazinews_pro_is_gallery_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'magazinews_pro_theme_options[gallery_title]', array(
		'selector'            => '#gallery-posts .section-header-wrapper .section-header h2.section-title',
		'settings'            => 'magazinews_pro_theme_options[gallery_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'magazinews_pro_gallery_title_partial',
    ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'magazinews_pro_theme_options[gallery_content_category]', array(
	'sanitize_callback' => 'magazinews_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Magazinews_Pro_Dropdown_Category_Control( $wp_customize,'magazinews_pro_theme_options[gallery_content_category]', array(
	'label'             => esc_html__( 'Select Categories', 'magazinews-pro' ),
	'description'      	=> esc_html__( 'Note: Press CTRL and select multiple category. Latest seven posts will be shown from each selected category', 'magazinews-pro' ),
	'section'           => 'magazinews_pro_gallery_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'magazinews_pro_is_gallery_section_enable',
) ) );

// gallery image setting and control.
$wp_customize->add_setting( 'magazinews_pro_theme_options[gallery_ads]', array(
	'sanitize_callback' => 'magazinews_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'magazinews_pro_theme_options[gallery_ads]',
		array(
		'label'       		=> esc_html__( 'Ads Image', 'magazinews-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'magazinews-pro' ), 1920, 250 ),
		'section'     		=> 'magazinews_pro_gallery_section',
		'active_callback'	=> 'magazinews_pro_is_gallery_section_enable',
) ) );

// gallery ads alt setting and control
$wp_customize->add_setting( 'magazinews_pro_theme_options[gallery_ads_alt]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'magazinews_pro_theme_options[gallery_ads_alt]', array(
	'label'           	=> esc_html__( 'Ads Image Alt Text', 'magazinews-pro' ),
	'section'        	=> 'magazinews_pro_gallery_section',
	'active_callback' 	=> 'magazinews_pro_is_gallery_section_enable',
	'type'				=> 'text',
) );

// gallery ads url setting and control
$wp_customize->add_setting( 'magazinews_pro_theme_options[gallery_ads_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'magazinews_pro_theme_options[gallery_ads_url]', array(
	'label'           	=> esc_html__( 'Ads Image Url', 'magazinews-pro' ),
	'section'        	=> 'magazinews_pro_gallery_section',
	'active_callback' 	=> 'magazinews_pro_is_gallery_section_enable',
	'type'				=> 'url',
) );
